/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2023  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#ifndef _GCTL_CLI_VIEWER_H
#define _GCTL_CLI_VIEWER_H

#include <fstream>
#include <iostream>
#include <vector>
#include <ncurses.h>

namespace gctl
{
    // 命令行查看器，用于在终端内查看文本文件内容，支持上下左右鼠标滚动或按键导航和退出查看
    class cli_viewer
    {
    public:
        // 构造函数
        cli_viewer();
        // 析构函数
        ~cli_viewer();
        // 设置显示内容
        void setData(const std::vector<std::string>& data);
        // 添加显示内容
        void addData(const std::string& l);
        // 显示文件内容并进入查看循环
        void display();

    private:
        std::vector<std::string> lines; // 存储文件内容
    };
};

#endif // _GCTL_CLI_VIEWER_H